@@ -2,7 +2,7 @@ __author__ = 'Julian Togelius, julian@idsia.ch'
 
 from scipy import array
 
-from pybrain.rl import Agent
+from pybrain.rl.agents.agent import Agent
 
 
 class SimpleController(Agent):
@@ -13,8 +13,8 @@ class SimpleController(Agent):
         self.distanceToCurrentWP = obs[2]
         self.angleToNextWP = obs[3]
         self.distanceToNextWP = obs[4]
-        self.angleToOtherVehicle =obs[5]
-        self.distanceToOtherVehicle =obs[6]
+        self.angleToOtherVehicle = obs[5]
+        self.distanceToOtherVehicle = obs[6]
         
         
     def getAction(self):
@@ -28,4 +28,4 @@ class SimpleController(Agent):
             steering = 1
         print "speed", self.speed, "angle", self.angleToCurrentWP, "driving", driving, "steering", steering
         return array([driving, steering])
-        
\ No newline at end of file
+        
