@@ -1,6 +1,6 @@
 __author__ = 'Julian Togelius, julian@idsia.ch'
 
-from pybrain.rl.tasks import EpisodicTask
+from pybrain.rl.environments import EpisodicTask
 from simpleracetcp import SimpleraceEnvironment
 
 class SimpleraceTask(EpisodicTask):
@@ -32,4 +32,4 @@ class SimpleraceTask(EpisodicTask):
         self.environment = SimpleraceEnvironment()
         EpisodicTask.__init__(self, self.environment)
         self.t = 0
-        
\ No newline at end of file
+        
