@@ -2,14 +2,16 @@ __author__ = 'Thomas Rueckstiess, ruecksti@in.tum.de'
 
 from experiment import Experiment
 
+
 class ContinuousExperiment(Experiment):
     """ The extension of Experiment to handle continuous tasks. """
     
     def doInteractionsAndLearn(self, number = 1):
-        """ executes a number of steps while learning continuously.
+        """ Execute a number of steps while learning continuously.
             no reset is performed, such that consecutive calls to 
             this function can be made.
-        """
-        for dummy in range(number):
+        """ 
+        for _ in range(number):
             self._oneInteraction()
             self.agent.learn()
+        return self.stepid
