@@ -6,7 +6,7 @@ from pybrain.utilities import abstractMethod, Named
     
         
 class Evolvable(Named):
-    """ The interface for all evolvables, i.e. which implement mutation, randomize and copy operators. """   
+    """ The interface for all Evolvables, i.e. which implement mutation, randomize and copy operators. """   
         
     def mutate(self, **args):
         """ Vary some properties of the underlying module, so that it's behavior 
@@ -14,15 +14,16 @@ class Evolvable(Named):
         abstractMethod()
         
     def copy(self):
-        """ by default a full deep copy - subclasses should implement something faster, if appropriate. """
+        """ By default, returns a full deep-copy - subclasses should implement something faster, if appropriate. """
         return copy.deepcopy(self)
         
     def randomize(self):
-        """ randomly set all variable parameters """
+        """ Sets all variable parameters to random values. """
         abstractMethod()
         
     def newSimilarInstance(self):
-        """ generate a new Evolvable with the same maximal complexity """
+        """ Generates a new Evolvable of the same kind."""
         res = self.copy()
         res.randomize()
-        return res
\ No newline at end of file
+        return res
+    
\ No newline at end of file
